@@ -3,31 +3,28 @@
 Modern CLI for SutraGraph - Interactive command-line interface with provider setup and agent management.
 """
 
-import sys
 import json
+import sys
 from pathlib import Path
-from typing import Dict, Any
-from rich.panel import Panel
-from rich.prompt import Prompt, Confirm
-from rich.table import Table
-from rich.text import Text
-from rich.align import Align
+from typing import Any, Dict
 
 # Prompt toolkit imports for arrow key navigation
 from prompt_toolkit import Application, prompt
-from prompt_toolkit.layout import Layout, HSplit
+from prompt_toolkit.key_binding import KeyBindings
+from prompt_toolkit.layout import HSplit, Layout
 from prompt_toolkit.layout.containers import Window
 from prompt_toolkit.layout.controls import FormattedTextControl
-from prompt_toolkit.key_binding import KeyBindings
 from prompt_toolkit.styles import Style
+from rich.align import Align
+from rich.panel import Panel
+from rich.prompt import Confirm, Prompt
+from rich.table import Table
+from rich.text import Text
 
+from src.agent_management.prerequisites.agent_config import get_agent_registry
 from src.agents_new import Agent
-from src.utils.console import console
 from src.config.settings import reload_config
-from src.agent_management.prerequisites.agent_config import (
-    get_agent_registry,
-)
-
+from src.utils.console import console
 from src.utils.logging import setup_logging
 
 
@@ -64,7 +61,7 @@ class ModernSutraKit:
             Align.center(Text(banner, style="bold blue")),
             title="🚀 Welcome to SutraGraph",
             subtitle="AI-Powered Code Analysis & Automation",
-            border_style="bright_blue"
+            border_style="bright_blue",
         )
         console.print(panel)
 
@@ -74,11 +71,11 @@ class ModernSutraKit:
             if not self.config_path.exists():
                 return False
 
-            with open(self.config_path, 'r') as f:
+            with open(self.config_path, "r") as f:
                 config_data = json.load(f)
 
-            llm_config = config_data.get('llm', {})
-            provider = llm_config.get('provider')
+            llm_config = config_data.get("llm", {})
+            provider = llm_config.get("provider")
 
             if not provider:
                 return False
@@ -89,16 +86,39 @@ class ModernSutraKit:
                 return False
 
             # Basic validation for each provider
-            if provider == 'aws':
-                required_fields = ['access_key_id', 'secret_access_key', 'model_id', 'region']
+            if provider == "aws_bedrock":
+                required_fields = [
+                    "access_key_id",
+                    "secret_access_key",
+                    "model_id",
+                    "region",
+                ]
                 return all(provider_config.get(field) for field in required_fields)
-            elif provider == 'anthropic':
-                return bool(provider_config.get('api_key') and provider_config.get('model_id'))
-            elif provider == 'gcp':
-                required_fields = ['api_key', 'project_id', 'location']
+            elif provider == "anthropic":
+                return bool(
+                    provider_config.get("api_key") and provider_config.get("model_id")
+                )
+            elif provider == "openai":
+                return bool(
+                    provider_config.get("api_key") and provider_config.get("model_id")
+                )
+            elif provider == "google_ai":
+                return bool(
+                    provider_config.get("api_key")
+                    and provider_config.get("model_id")
+                    and provider_config.get("base_url")
+                )
+            elif provider == "vertex_ai":
+                return bool(
+                    provider_config.get("location") and provider_config.get("model_id")
+                )
+            elif provider == "azure_openai":
+                required_fields = [
+                    "api_key",
+                    "base_url",
+                    "api_version",
+                ]
                 return all(provider_config.get(field) for field in required_fields)
-            elif provider == 'openai':
-                return bool(provider_config.get('api_key') and provider_config.get('model_id'))
 
             return True
 
@@ -109,13 +129,10 @@ class ModernSutraKit:
         """Interactive LLM provider setup with arrow keys."""
         console.info("LLM Provider Setup")
 
-        providers = [
-            {"name": "Anthropic (Claude)", "key": "anthropic",
-             "description": "Claude models (claude-3.5-sonnet, etc.)"},
-            {"name": "AWS Bedrock", "key": "aws", "description": "AWS managed AI services"},
-            {"name": "Google Gemini", "key": "gcp", "description": "Google's Gemini models"},
-            {"name": "OpenAI (ChatGPT)", "key": "openai", "description": "GPT models via OpenAI API"}
-        ]
+        # Import providers from centralized config
+        from src.config.settings import get_provider_info
+
+        providers = get_provider_info()
 
         table = Table()
         table.add_column("Provider", style="green")
@@ -138,8 +155,8 @@ class ModernSutraKit:
         # Collect provider-specific configuration
         config_data = self._get_provider_config(provider_key)
 
-        # Update only the LLM configuration
-        updated_config = self._update_llm_config(provider_key, config_data)
+        # Update the provider configuration in existing config
+        updated_config = self._update_provider_config(provider_key, config_data)
 
         # Save configuration
         self._save_config(updated_config)
@@ -148,12 +165,16 @@ class ModernSutraKit:
 
     def _get_provider_config(self, provider: str) -> Dict[str, Any]:
         """Get configuration for specific provider."""
-        if provider == "aws":
+        if provider == "aws_bedrock":
             return self._get_aws_config()
         elif provider == "anthropic":
             return self._get_anthropic_config()
-        elif provider == "gcp":
-            return self._get_gcp_config()
+        elif provider == "google_ai":
+            return self._get_gemini_config()
+        elif provider == "vertex_ai":
+            return self._get_vertex_ai_config()
+        elif provider == "azure_openai":
+            return self._get_azure_config()
         elif provider == "openai":
             return self._get_openai_config()
         else:
@@ -165,13 +186,15 @@ class ModernSutraKit:
         access_key = Prompt.ask("AWS Access Key ID", password=False)
         secret_key = prompt("AWS Secret Access Key: ", is_password=True)
         region = Prompt.ask("AWS Region", default="us-east-2")
-        model_id = Prompt.ask("Model ID", default="us.anthropic.claude-sonnet-4-20250514-v1:0")
+        model_id = Prompt.ask(
+            "Model ID", default="us.anthropic.claude-sonnet-4-20250514-v1:0"
+        )
 
         return {
             "access_key_id": access_key,
             "secret_access_key": secret_key,
             "region": region,
-            "model_id": model_id
+            "model_id": model_id,
         }
 
     def _get_anthropic_config(self) -> Dict[str, Any]:
@@ -180,25 +203,130 @@ class ModernSutraKit:
         api_key = prompt("Anthropic API Key: ", is_password=True)
         model_id = Prompt.ask("Model ID", default="claude-3-5-sonnet-20241022")
 
-        return {
-            "api_key": api_key,
-            "model_id": model_id
-        }
+        return {"api_key": api_key, "model_id": model_id}
 
-    def _get_gcp_config(self) -> Dict[str, Any]:
-        """Get Google Cloud configuration."""
-        console.info("Google Cloud Configuration")
-        api_key = prompt("Google API Key: ", is_password=True)
-        project_id = Prompt.ask("Project ID")
-        location = Prompt.ask("Location", default="us-central1")
-        llm_endpoint = Prompt.ask("LLM Endpoint", default="")
+    def _get_gemini_config(self) -> Dict[str, Any]:
+        """Get Google Gemini configuration."""
+        console.info("Google Gemini Configuration")
+        api_key = prompt("Gemini API Key: ", is_password=True)
+        model_id = Prompt.ask("Model ID", default="gemini-1.5-pro")
+        base_url = Prompt.ask(
+            "Base URL", default="https://generativelanguage.googleapis.com/v1beta"
+        )
 
-        return {
-            "api_key": api_key,
-            "project_id": project_id,
-            "location": location,
-            "llm_endpoint": llm_endpoint
-        }
+        return {"api_key": api_key, "model_id": model_id, "base_url": base_url}
+
+    def _get_vertex_ai_config(self) -> Dict[str, Any]:
+        """Get Google Cloud Vertex AI configuration with gcloud authentication."""
+        console.info("Google Cloud Vertex AI Configuration")
+        console.print()
+        console.info("Vertex AI uses Google Cloud authentication via gcloud CLI.")
+        console.print("Please ensure you have:")
+        console.print(
+            "  1. Google Cloud SDK installed (https://cloud.google.com/sdk/docs/install)"
+        )
+        console.print(
+            "  2. Run: gcloud init (to set up your default project and authentication)"
+        )
+        console.print("  3. Vertex AI API enabled in your project")
+        console.print("  4. Proper permissions for Vertex AI")
+        console.print()
+
+        # Prompt for authentication
+        if Confirm.ask("Do you want to authenticate with Google Cloud now?"):
+            self._setup_gcp_auth()
+        else:
+            console.warning(
+                "You can authenticate later using: gcloud auth application-default login --project YOUR_PROJECT_ID"
+            )
+
+        # Get basic configuration
+        location = Prompt.ask("Location (region)", default="global")
+        model_id = Prompt.ask("Model ID", default="gemini-2.5-pro")
+
+        return {"location": location, "model_id": model_id}
+
+    def _setup_gcp_auth(self):
+        """Guide user through GCP authentication setup with retry option."""
+        import subprocess
+        import sys
+
+        console.info("Setting up Google Cloud authentication...")
+
+        # Check if gcloud is installed
+        try:
+            result = subprocess.run(
+                ["gcloud", "--version"], capture_output=True, text=True
+            )
+            if result.returncode != 0:
+                console.error("Google Cloud SDK (gcloud) is not installed.")
+                console.info(
+                    "Please install it from: https://cloud.google.com/sdk/docs/install"
+                )
+                console.info("After installation, run: gcloud init")
+                return
+        except FileNotFoundError:
+            console.error("Google Cloud SDK (gcloud) is not installed or not in PATH.")
+            console.info(
+                "Please install it from: https://cloud.google.com/sdk/docs/install"
+            )
+            console.info("After installation, run: gcloud init")
+            return
+
+        # Retry loop for authentication
+        while True:
+            # Get project ID
+            project_id = Prompt.ask("Enter your Google Cloud Project ID")
+
+            # Run authentication command
+            console.info(
+                f"Running: gcloud auth application-default login --project {project_id}"
+            )
+            console.info("This will open your browser for authentication...")
+
+            try:
+                result = subprocess.run(
+                    [
+                        "gcloud",
+                        "auth",
+                        "application-default",
+                        "login",
+                        "--project",
+                        project_id,
+                    ],
+                    check=True,
+                )
+
+                if result.returncode == 0:
+                    console.success("Google Cloud authentication successful!")
+                    console.info("Vertex AI is now ready to use.")
+                    return  # Success, exit the retry loop
+
+            except subprocess.CalledProcessError as e:
+                console.error(f"Authentication failed: {e}")
+                console.info("Steps:")
+                console.info("1. Run: gcloud init (if not done already)")
+                console.info(
+                    f"2. Run: gcloud auth application-default login --project {project_id}"
+                )
+            except Exception as e:
+                console.error(f"Unexpected error: {e}")
+                console.info("Steps:")
+                console.info("1. Run: gcloud init (if not done already)")
+                console.info(
+                    f"2. Run: gcloud auth application-default login --project {project_id}"
+                )
+
+            # Ask if user wants to retry
+            console.print()
+            if not Confirm.ask(
+                "Would you like to try again with a different project ID or retry authentication?",
+                default=True,
+            ):
+                console.warning(
+                    "Authentication setup cancelled. You can set up authentication manually later."
+                )
+                break
 
     def _get_openai_config(self) -> Dict[str, Any]:
         """Get OpenAI configuration."""
@@ -206,37 +334,72 @@ class ModernSutraKit:
         api_key = prompt("OpenAI API Key: ", is_password=True)
         model_id = Prompt.ask("Model ID", default="gpt-4o")
 
+        return {"api_key": api_key, "model_id": model_id}
+
+    def _get_azure_config(self) -> Dict[str, Any]:
+        """Get Azure OpenAI configuration."""
+        console.info("Azure OpenAI Configuration")
+        api_key = prompt("Azure OpenAI API Key: ", is_password=True)
+
+        console.print()
+        console.info(
+            "Base URL Example: https://your-resource-name.openai.azure.com/openai/deployments/your-deployment-id"
+        )
+        console.dim(
+            "Replace 'your-resource-name' with your Azure resource name and 'your-deployment-id' with your deployment ID"
+        )
+        console.print()
+
+        base_url = Prompt.ask("Base URL")
+        api_version = Prompt.ask("API Version", default="2025-01-01-preview")
+
         return {
             "api_key": api_key,
-            "model_id": model_id
+            "base_url": base_url,
+            "api_version": api_version,
         }
 
-    def _load_existing_config(self) -> Dict[str, Any]:
-        """Load existing configuration or exit if not found."""
-        if not self.config_path.exists():
-            console.error("Configuration file not found. Did you run the 'sutrakit-setup' command?")
-            console.info("Please run 'sutrakit-setup' first to initialize the system configuration.")
-            sys.exit(1)
+    def _update_provider_config(self, provider: str, provider_config: Dict[str, Any]):
+        """Update only the provider configuration in existing config file."""
+        # Load existing config or create minimal structure if it doesn't exist
+        if self.config_path.exists():
+            try:
+                with open(self.config_path, "r") as f:
+                    existing_config = json.load(f)
+            except (json.JSONDecodeError, FileNotFoundError):
+                existing_config = {}
+        else:
+            existing_config = {}
 
-        try:
-            with open(self.config_path, 'r') as f:
-                return json.load(f)
-        except json.JSONDecodeError as e:
-            console.error(f"Invalid JSON in configuration file: {e}")
-            console.error("Configuration file appears to be corrupted. Please run 'sutrakit-setup' again.")
-            sys.exit(1)
-        except Exception as e:
-            console.error(f"Error reading configuration file: {e}")
-            sys.exit(1)
-
-    def _update_llm_config(self, provider: str, provider_config: Dict[str, Any]) -> Dict[str, Any]:
-        """Update only the LLM configuration, preserving other settings."""
-        # Load existing configuration (will exit if not found)
-        existing_config = self._load_existing_config()
+        # Ensure llm section exists
+        if "llm" not in existing_config:
+            existing_config["llm"] = {}
 
+        # Update provider and max_tokens
         existing_config["llm"]["provider"] = provider
 
-        existing_config["llm"][provider] = provider_config
+        # Initialize all provider sections if they don't exist
+        provider_keys = [
+            "aws_bedrock",
+            "anthropic",
+            "google_ai",
+            "vertex_ai",
+            "azure_openai",
+            "openai",
+            "superllm",
+        ]
+        for key in provider_keys:
+            if key not in existing_config["llm"]:
+                existing_config["llm"][key] = {}
+
+        # Update only the fields provided by the user, preserving existing fields
+        if provider in existing_config["llm"]:
+            # Merge new config with existing provider config
+            for field_key, field_value in provider_config.items():
+                existing_config["llm"][provider][field_key] = field_value
+        else:
+            # If provider section doesn't exist, create it with the new config
+            existing_config["llm"][provider] = provider_config
 
         return existing_config
 
@@ -245,11 +408,14 @@ class ModernSutraKit:
         # Ensure config directory exists
         self.config_path.parent.mkdir(parents=True, exist_ok=True)
 
-        with open(self.config_path, 'w') as f:
+        with open(self.config_path, "w") as f:
             json.dump(config, f, indent=2)
 
         # Reload the configuration to update the in-memory instance
         reload_config()
+        from cli.setup import setup_baml_environment
+
+        setup_baml_environment()
 
     def select_agent(self) -> Agent:
         """Interactive agent selection with arrow keys."""
@@ -287,52 +453,63 @@ class ModernSutraKit:
         current_index = 0
 
         def get_formatted_text():
-            lines = [('', 'Select LLM provider (↑↓ to navigate, Enter to select, Esc to cancel):\n\n')]
+            lines = [
+                (
+                    "",
+                    "Select LLM provider (↑↓ to navigate, Enter to select, Esc to cancel):\n\n",
+                )
+            ]
 
             for i, provider in enumerate(providers):
                 if i == current_index:
-                    lines.append(('class:selected', f'▶ {provider["name"]}\n'))
+                    lines.append(("class:selected", f'▶ {provider["name"]}\n'))
                 else:
-                    lines.append(('', f'  {provider["name"]}\n'))
+                    lines.append(("", f'  {provider["name"]}\n'))
 
             return lines
 
         # Key bindings
         bindings = KeyBindings()
 
-        @bindings.add('up')
+        @bindings.add("up")
         def move_up(event):
             nonlocal current_index
             current_index = (current_index - 1) % len(providers)
 
-        @bindings.add('down')
+        @bindings.add("down")
         def move_down(event):
             nonlocal current_index
             current_index = (current_index + 1) % len(providers)
 
-        @bindings.add('enter')
+        @bindings.add("enter")
         def select_item(event):
             event.app.exit(result=providers[current_index])
 
-        @bindings.add('escape')
-        @bindings.add('c-c')
+        @bindings.add("escape")
+        @bindings.add("c-c")
         def cancel(event):
             event.app.exit(result=None)
 
         # Create the application
         application = Application(
             layout=Layout(
-                HSplit([
-                    Window(FormattedTextControl(get_formatted_text), wrap_lines=True),
-                ])
+                HSplit(
+                    [
+                        Window(
+                            FormattedTextControl(get_formatted_text), wrap_lines=True
+                        ),
+                    ]
+                )
             ),
             key_bindings=bindings,
             mouse_support=False,
             full_screen=False,
-            style=Style([
-                ('selected', 'bg:#0066cc #ffffff bold'),
-                ('dim', '#666666'),
-            ])
+            style=Style(
+                [
+                    ("selected", "bg:#0066cc #ffffff bold"),
+                    ("dim", "#666666"),
+                ]
+            ),
         )
 
         # Run the application
@@ -343,52 +520,63 @@ class ModernSutraKit:
         current_index = 0
 
         def get_formatted_text():
-            lines = [('', 'Select agent (↑↓ to navigate, Enter to select, Esc to cancel):\n\n')]
+            lines = [
+                (
+                    "",
+                    "Select agent (↑↓ to navigate, Enter to select, Esc to cancel):\n\n",
+                )
+            ]
 
             for i, agent in enumerate(agents):
                 if i == current_index:
-                    lines.append(('class:selected', f'▶ {agent.name}'))
+                    lines.append(("class:selected", f"▶ {agent.name}"))
                 else:
-                    lines.append(('', f'  {agent.name}'))
+                    lines.append(("", f"  {agent.name}"))
 
             return lines
 
         # Key bindings
         bindings = KeyBindings()
 
-        @bindings.add('up')
+        @bindings.add("up")
         def move_up(event):
             nonlocal current_index
             current_index = (current_index - 1) % len(agents)
 
-        @bindings.add('down')
+        @bindings.add("down")
         def move_down(event):
             nonlocal current_index
             current_index = (current_index + 1) % len(agents)
 
-        @bindings.add('enter')
+        @bindings.add("enter")
         def select_item(event):
             event.app.exit(result=agents[current_index])
 
-        @bindings.add('escape')
-        @bindings.add('c-c')
+        @bindings.add("escape")
+        @bindings.add("c-c")
         def cancel(event):
             event.app.exit(result=None)
 
         # Create the application
         application = Application(
             layout=Layout(
-                HSplit([
-                    Window(FormattedTextControl(get_formatted_text), wrap_lines=True),
-                ])
+                HSplit(
+                    [
+                        Window(
+                            FormattedTextControl(get_formatted_text), wrap_lines=True
+                        ),
+                    ]
+                )
             ),
             key_bindings=bindings,
             mouse_support=False,
             full_screen=False,
-            style=Style([
-                ('selected', 'bg:#0066cc #ffffff bold'),
-                ('dim', '#666666'),
-            ])
+            style=Style(
+                [
+                    ("selected", "bg:#0066cc #ffffff bold"),
+                    ("dim", "#666666"),
+                ]
+            ),
         )
 
         # Run the application
@@ -477,8 +665,8 @@ class ModernSutraKit:
 
         # Check if cross-indexing is already completed
         try:
-            from src.services.project_manager import ProjectManager
             from src.graph.graph_operations import GraphOperations
+            from src.services.project_manager import ProjectManager
 
             project_manager = ProjectManager()
             graph_ops = GraphOperations()
@@ -486,7 +674,9 @@ class ModernSutraKit:
             project_name = project_manager.determine_project_name(project_dir)
 
             if graph_ops.is_cross_indexing_done(project_name):
-                console.success(f"Cross-indexing already completed for project '{project_name}'")
+                console.success(
+                    f"Cross-indexing already completed for project '{project_name}'"
+                )
                 console.dim("📊 Skipping analysis - project already fully analyzed")
                 return
 
@@ -523,7 +713,9 @@ Closing the terminal or interrupting may lead to incomplete data and token wasta
 
         if not proceed:
             console.warning("Cross-indexing declined by user.")
-            console.dim("💡 Tip: You can run this later when you're ready to spend the time and tokens.")
+            console.dim(
+                "💡 Tip: You can run this later when you're ready to spend the time and tokens."
+            )
             console.dim("📝 To continue later, simply run the same command again.")
             # Raise a custom exception to stop the workflow
             raise UserCancelledError("User declined cross-indexing analysis")
@@ -558,7 +750,9 @@ Closing the terminal or interrupting may lead to incomplete data and token wasta
             from cli.commands import handle_agent_command
 
             # Execute the agent - post-processing is handled internally by the agent service
-            agent_result = handle_agent_command(agent_name=agent_name, project_path=project_dir)
+            agent_result = handle_agent_command(
+                agent_name=agent_name, project_path=project_dir
+            )
 
             if agent_result:
                 console.success("Agent execution completed successfully!!!")
