@@ -1,20 +1,22 @@
 """Main module for testing Python relationship extraction."""
 
 # Standard library import
+# Dynamic import (using importlib)
+import importlib
 import os
 import sys
 from pathlib import Path
 
+# Absolute imports (assuming this is part of a package)
+import test_relationships.python.module1 as mod1
+
 # Relative imports
 from .module1 import function1
 from .subpackage import module2
 
-# Absolute imports (assuming this is part of a package)
-import test_relationships.python.module1 as mod1
-
-# Dynamic import (using importlib)
-import importlib
-dynamic_module = importlib.import_module('.module1', package='test_relationships.python')
+dynamic_module = importlib.import_module(
+    ".module1", package="test_relationships.python"
+)
 
 
 def main():
@@ -27,4 +29,4 @@ def main():
 
 
 if __name__ == "__main__":
-    main()
\ No newline at end of file
+    main()
