@@ -2,18 +2,17 @@
 Models module initialization.
 """
 
+from models.agent import AgentAction
+
 # All models now in schema.py
 from models.schema import (
-    File,
-    Project,
-    CodeBlock,
-    Relationship,
-    FileData,
-    ExtractionData,
     BlockType,
-)
-from models.agent import (
-    AgentAction,
+    CodeBlock,
+    ExtractionData,
+    File,
+    FileData,
+    Project,
+    Relationship,
 )
 
 __all__ = [
