@@ -5,19 +5,22 @@ Handles updating Sutra memory when code changes happen during incremental indexi
 This module ensures that stored code snippets remain accurate when files are modified.
 """
 
-from typing import Dict, List, Optional, Set, Tuple, Any
-from pathlib import Path
-from loguru import logger
 from dataclasses import dataclass
+from pathlib import Path
+from typing import Any, Dict, List, Optional, Set, Tuple
+
+from loguru import logger
+
 from graph.graph_operations import GraphOperations
 
-from .models import CodeSnippet
 from .memory_operations import MemoryOperations
+from .models import CodeSnippet
 
 
 @dataclass
 class LineChange:
     """Represents a line number change in a file"""
+
     line_number: int
     change_type: str  # "insert" or "delete"
     change_amount: int  # number of lines added/removed
@@ -26,6 +29,7 @@ class LineChange:
 @dataclass
 class CodeUpdate:
     """Represents an update to a code snippet"""
+
     code_id: str
     new_start_line: int
     new_end_line: int
@@ -41,19 +45,16 @@ class MemoryUpdater:
         self.graph_ops = GraphOperations()
 
     def update_memory_for_file_changes(
-        self,
-        changed_files: Set[Path],
-        deleted_files: Set[Path],
-        project_id: int
+        self, changed_files: Set[Path], deleted_files: Set[Path], project_id: int
     ) -> Dict[str, Any]:
         """
         Update Sutra memory when files change during incremental indexing.
-        
+
         Args:
             changed_files: Set of file paths that were modified
             deleted_files: Set of file paths that were deleted
             project_id: Project ID for database queries
-            
+
         Returns:
             Dict with update statistics
         """
@@ -62,16 +63,20 @@ class MemoryUpdater:
             "codes_removed": 0,
             "line_number_updates": 0,
             "content_updates": 0,
-            "files_processed": 0
+            "files_processed": 0,
         }
 
         try:
             # Get all stored code snippets
             all_code_snippets = self.memory_ops.get_all_code_snippets()
 
-            logger.debug(f"Memory updater found {len(all_code_snippets)} code snippets in memory")
+            logger.debug(
+                f"Memory updater found {len(all_code_snippets)} code snippets in memory"
+            )
             for snippet_id, snippet in all_code_snippets.items():
-                logger.debug(f"  - {snippet_id}: {snippet.file_path} (lines {snippet.start_line}-{snippet.end_line})")
+                logger.debug(
+                    f"  - {snippet_id}: {snippet.file_path} (lines {snippet.start_line}-{snippet.end_line})"
+                )
 
             if not all_code_snippets:
                 logger.debug("No code snippets in memory to update")
@@ -91,9 +96,13 @@ class MemoryUpdater:
             # Process changed files
             for file_path in changed_files:
                 file_path_str = str(file_path)
-                file_updates = self._update_code_snippets_for_file(file_path_str, project_id)
+                file_updates = self._update_code_snippets_for_file(
+                    file_path_str, project_id
+                )
                 updates_made["codes_updated"] += file_updates["codes_updated"]
-                updates_made["line_number_updates"] += file_updates["line_number_updates"]
+                updates_made["line_number_updates"] += file_updates[
+                    "line_number_updates"
+                ]
                 updates_made["content_updates"] += file_updates["content_updates"]
 
                 if file_updates["codes_updated"] > 0:
@@ -102,7 +111,9 @@ class MemoryUpdater:
                         f"🔄 Updated {file_updates['codes_updated']} code snippets for file: {file_path}"
                     )
 
-            total_updates = updates_made["codes_updated"] + updates_made["codes_removed"]
+            total_updates = (
+                updates_made["codes_updated"] + updates_made["codes_removed"]
+            )
             if total_updates > 0:
                 logger.debug(
                     f"✅ Memory update completed: {total_updates} code snippets processed"
@@ -123,17 +134,17 @@ class MemoryUpdater:
         for code_snippet in code_snippets:
             if self.memory_ops.remove_code_snippet(code_snippet.id):
                 removed_count += 1
-                logger.debug(f"Removed code snippet {code_snippet.id} for deleted file {file_path}")
+                logger.debug(
+                    f"Removed code snippet {code_snippet.id} for deleted file {file_path}"
+                )
 
         return removed_count
 
-    def _update_code_snippets_for_file(self, file_path: str, project_id: int) -> Dict[str, int]:
+    def _update_code_snippets_for_file(
+        self, file_path: str, project_id: int
+    ) -> Dict[str, int]:
         """Update code snippets for a changed file"""
-        updates = {
-            "codes_updated": 0,
-            "line_number_updates": 0,
-            "content_updates": 0
-        }
+        updates = {"codes_updated": 0, "line_number_updates": 0, "content_updates": 0}
 
         logger.debug(f"Updating code snippets for file: {file_path}")
 
@@ -142,7 +153,9 @@ class MemoryUpdater:
 
         logger.debug(f"Found {len(code_snippets)} code snippets for file {file_path}")
         for snippet in code_snippets:
-            logger.debug(f"  - {snippet.id}: lines {snippet.start_line}-{snippet.end_line}")
+            logger.debug(
+                f"  - {snippet.id}: lines {snippet.start_line}-{snippet.end_line}"
+            )
 
         if not code_snippets:
             logger.debug(f"No code snippets found for file {file_path}")
@@ -169,16 +182,22 @@ class MemoryUpdater:
                     if update_info.should_remove:
                         # Remove code snippet if content no longer exists
                         self.memory_ops.remove_code_snippet(code_snippet.id)
-                        logger.debug(f"Removed code snippet {code_snippet.id} - content no longer exists")
+                        logger.debug(
+                            f"Removed code snippet {code_snippet.id} - content no longer exists"
+                        )
                     else:
                         # Update the code snippet
-                        success = self._apply_code_snippet_update(code_snippet, update_info)
+                        success = self._apply_code_snippet_update(
+                            code_snippet, update_info
+                        )
                         if success:
                             updates["codes_updated"] += 1
                             if update_info.new_content:
                                 updates["content_updates"] += 1
-                            if (update_info.new_start_line != code_snippet.start_line or 
-                                update_info.new_end_line != code_snippet.end_line):
+                            if (
+                                update_info.new_start_line != code_snippet.start_line
+                                or update_info.new_end_line != code_snippet.end_line
+                            ):
                                 updates["line_number_updates"] += 1
 
                             logger.debug(
@@ -187,16 +206,21 @@ class MemoryUpdater:
                                 f"{update_info.new_start_line}-{update_info.new_end_line}"
                             )
                 else:
-                    logger.debug(f"No updates needed for code snippet {code_snippet.id}")
+                    logger.debug(
+                        f"No updates needed for code snippet {code_snippet.id}"
+                    )
 
             except Exception as e:
                 logger.error(f"Error updating code snippet {code_snippet.id}: {e}")
                 import traceback
+
                 traceback.print_exc()
 
         return updates
 
-    def _get_current_file_content(self, file_path: str, project_id: int) -> Optional[str]:
+    def _get_current_file_content(
+        self, file_path: str, project_id: int
+    ) -> Optional[str]:
         """Get current file content from database using graph_operations"""
         try:
             import os
@@ -235,7 +259,9 @@ class MemoryUpdater:
 
             # Try each path variation using graph_operations
             for path_variant in path_variations:
-                logger.debug(f"Trying to find file content for path variant: {path_variant}")
+                logger.debug(
+                    f"Trying to find file content for path variant: {path_variant}"
+                )
 
                 file_id = self.graph_ops._get_file_id_by_path(path_variant)
                 if file_id:
@@ -244,7 +270,9 @@ class MemoryUpdater:
                         logger.debug(f"Found database content for {path_variant}")
                         return file_data.get("content", "")
 
-            logger.debug(f"No database content found for {file_path} (tried {len(path_variations)} variations)")
+            logger.debug(
+                f"No database content found for {file_path} (tried {len(path_variations)} variations)"
+            )
             return None
 
         except Exception as e:
@@ -256,11 +284,11 @@ class MemoryUpdater:
     ) -> Optional[CodeUpdate]:
         """
         Analyze changes to a code snippet and determine required updates.
-        
+
         Args:
             code_snippet: The stored code snippet
             current_content: Current file content from database
-            
+
         Returns:
             CodeUpdate object if updates are needed, None otherwise
         """
@@ -269,13 +297,15 @@ class MemoryUpdater:
                 code_id=code_snippet.id,
                 new_start_line=0,
                 new_end_line=0,
-                should_remove=True
+                should_remove=True,
             )
 
-        current_lines = current_content.split('\n')
+        current_lines = current_content.split("\n")
 
         # Check if the original content still exists in the file
-        original_content_lines = code_snippet.content.split('\n') if code_snippet.content else []
+        original_content_lines = (
+            code_snippet.content.split("\n") if code_snippet.content else []
+        )
 
         if not original_content_lines:
             # If we don't have original content, we can't track changes
@@ -302,24 +332,28 @@ class MemoryUpdater:
             logger.debug(f"  {i+1}: {line}")
 
         # Try to find the content in the current file
-        new_location = self._find_content_in_file(stripped_original_lines, current_lines)
+        new_location = self._find_content_in_file(
+            stripped_original_lines, current_lines
+        )
 
         logger.debug(f"Content search result for {code_snippet.id}: {new_location}")
 
         if new_location is None:
             # Content not found - check if it was partially modified
-            fuzzy_location = self._find_similar_content(stripped_original_lines, current_lines)
+            fuzzy_location = self._find_similar_content(
+                stripped_original_lines, current_lines
+            )
 
             if fuzzy_location:
                 # Content found but modified - update both location and content
                 new_start, new_end = fuzzy_location
-                new_content = '\n'.join(current_lines[new_start-1:new_end])
+                new_content = "\n".join(current_lines[new_start - 1 : new_end])
 
                 return CodeUpdate(
                     code_id=code_snippet.id,
                     new_start_line=new_start,
                     new_end_line=new_end,
-                    new_content=new_content
+                    new_content=new_content,
                 )
             else:
                 # Content completely removed or significantly changed
@@ -327,7 +361,7 @@ class MemoryUpdater:
                     code_id=code_snippet.id,
                     new_start_line=0,
                     new_end_line=0,
-                    should_remove=True
+                    should_remove=True,
                 )
         else:
             # Content found at new location
@@ -338,7 +372,7 @@ class MemoryUpdater:
                 return CodeUpdate(
                     code_id=code_snippet.id,
                     new_start_line=new_start,
-                    new_end_line=new_end
+                    new_end_line=new_end,
                 )
 
         return None  # No changes needed
@@ -357,7 +391,7 @@ class MemoryUpdater:
 
         for i in range(len(file_lines) - content_length + 1):
             # Check if content matches at this position
-            if file_lines[i:i + content_length] == content_lines:
+            if file_lines[i : i + content_length] == content_lines:
                 return (i + 1, i + content_length)  # 1-indexed
 
         return None
@@ -380,7 +414,7 @@ class MemoryUpdater:
         best_similarity = 0
 
         for i in range(len(file_lines) - content_length + 1):
-            candidate_lines = file_lines[i:i + content_length]
+            candidate_lines = file_lines[i : i + content_length]
             similarity = self._calculate_similarity(content_lines, candidate_lines)
 
             if similarity > best_similarity and similarity >= similarity_threshold:
@@ -397,7 +431,9 @@ class MemoryUpdater:
         if not lines1:
             return 1.0
 
-        matching_lines = sum(1 for l1, l2 in zip(lines1, lines2) if l1.strip() == l2.strip())
+        matching_lines = sum(
+            1 for l1, l2 in zip(lines1, lines2) if l1.strip() == l2.strip()
+        )
         return matching_lines / len(lines1)
 
     def _apply_code_snippet_update(
@@ -418,16 +454,20 @@ class MemoryUpdater:
             return True
 
         except Exception as e:
-            logger.error(f"Error applying update to code snippet {code_snippet.id}: {e}")
+            logger.error(
+                f"Error applying update to code snippet {code_snippet.id}: {e}"
+            )
             return False
 
-    def detect_line_changes(self, old_content: str, new_content: str) -> List[LineChange]:
+    def detect_line_changes(
+        self, old_content: str, new_content: str
+    ) -> List[LineChange]:
         """
         Detect line insertions and deletions between old and new content.
         This is a simplified diff algorithm for detecting basic changes.
         """
-        old_lines = old_content.split('\n')
-        new_lines = new_content.split('\n')
+        old_lines = old_content.split("\n")
+        new_lines = new_content.split("\n")
 
         changes = []
 
@@ -442,52 +482,66 @@ class MemoryUpdater:
                 new_idx += 1
             else:
                 # Lines don't match, try to determine if it's insertion or deletion
-                if old_idx + 1 < len(old_lines) and old_lines[old_idx + 1] == new_lines[new_idx]:
+                if (
+                    old_idx + 1 < len(old_lines)
+                    and old_lines[old_idx + 1] == new_lines[new_idx]
+                ):
                     # Deletion in old content
-                    changes.append(LineChange(
-                        line_number=old_idx + 1,
-                        change_type="delete",
-                        change_amount=1
-                    ))
+                    changes.append(
+                        LineChange(
+                            line_number=old_idx + 1,
+                            change_type="delete",
+                            change_amount=1,
+                        )
+                    )
                     old_idx += 1
-                elif new_idx + 1 < len(new_lines) and old_lines[old_idx] == new_lines[new_idx + 1]:
+                elif (
+                    new_idx + 1 < len(new_lines)
+                    and old_lines[old_idx] == new_lines[new_idx + 1]
+                ):
                     # Insertion in new content
-                    changes.append(LineChange(
-                        line_number=new_idx + 1,
-                        change_type="insert",
-                        change_amount=1
-                    ))
+                    changes.append(
+                        LineChange(
+                            line_number=new_idx + 1,
+                            change_type="insert",
+                            change_amount=1,
+                        )
+                    )
                     new_idx += 1
                 else:
                     # Content changed, treat as both deletion and insertion
-                    changes.append(LineChange(
-                        line_number=old_idx + 1,
-                        change_type="delete",
-                        change_amount=1
-                    ))
-                    changes.append(LineChange(
-                        line_number=new_idx + 1,
-                        change_type="insert",
-                        change_amount=1
-                    ))
+                    changes.append(
+                        LineChange(
+                            line_number=old_idx + 1,
+                            change_type="delete",
+                            change_amount=1,
+                        )
+                    )
+                    changes.append(
+                        LineChange(
+                            line_number=new_idx + 1,
+                            change_type="insert",
+                            change_amount=1,
+                        )
+                    )
                     old_idx += 1
                     new_idx += 1
 
         # Handle remaining lines
         while old_idx < len(old_lines):
-            changes.append(LineChange(
-                line_number=old_idx + 1,
-                change_type="delete",
-                change_amount=1
-            ))
+            changes.append(
+                LineChange(
+                    line_number=old_idx + 1, change_type="delete", change_amount=1
+                )
+            )
             old_idx += 1
 
         while new_idx < len(new_lines):
-            changes.append(LineChange(
-                line_number=new_idx + 1,
-                change_type="insert",
-                change_amount=1
-            ))
+            changes.append(
+                LineChange(
+                    line_number=new_idx + 1, change_type="insert", change_amount=1
+                )
+            )
             new_idx += 1
 
         return changes
@@ -537,7 +591,7 @@ class MemoryUpdater:
                 end_line=max(new_start, new_end),  # Ensure end >= start
                 description=snippet.description,
                 content=snippet.content,
-                created_at=snippet.created_at
+                created_at=snippet.created_at,
             )
 
             updated_snippets.append(updated_snippet)
