@@ -1,4 +1,5 @@
-from typing import Iterator, Dict, Any
+from typing import Any, Dict, Iterator
+
 from models.agent import AgentAction
 
 
@@ -10,15 +11,11 @@ def execute_completion_action(action: AgentAction) -> Iterator[Dict[str, Any]]:
         result = params.get("result", "Task completed")
 
         yield {
-            "simple":True,
+            "simple": True,
             "type": "tool_use",
             "tool_name": "attempt_completion",
-            "data": {"result": result}
+            "data": {"result": result},
         }
 
     except Exception as e:
-        yield {
-            "type": "tool_error",
-            "tool_name": "attempt_completion",
-            "error": str(e)
-        }
+        yield {"type": "tool_error", "tool_name": "attempt_completion", "error": str(e)}
